==> config-api-0.3.8-sources.jar: org/wildfly/swarm/config/jca/ArchiveValidation.java <==
package org.wildfly.swarm.config.jca;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
/**
 * Archive validation for resource adapters
 */
@ResourceType("archive-validation")
@Implicit
public class ArchiveValidation {

	private String key;
	private Boolean enabled;
	private Boolean failOnError;
	private Boolean failOnWarn;

	public ArchiveValidation() {
		this.key = "archive-validation";
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Specify whether archive validation is enabled
	 */
	@ModelNodeBinding(detypedName = "enabled")
	public Boolean enabled() {
		return this.enabled;
	}

	/**
	 * Specify whether archive validation is enabled
	 */
	@SuppressWarnings("unchecked")
	public ArchiveValidation enabled(Boolean value) {
		this.enabled = value;
		return (ArchiveValidation) this;
	}

	/**
	 * Should an archive validation error report fail the deployment
	 */
	@ModelNodeBinding(detypedName = "fail-on-error")
	public Boolean failOnError() {
		return this.failOnError;
	}

	/**
	 * Should an archive validation error report fail the deployment
	 */
	@SuppressWarnings("unchecked")
	public ArchiveValidation failOnError(Boolean value) {
		this.failOnError = value;
		return (ArchiveValidation) this;
	}

	/**
	 * Should an archive validation warning report fail the deployment
	 */
	@ModelNodeBinding(detypedName = "fail-on-warn")
	public Boolean failOnWarn() {
		return this.failOnWarn;
	}

	/**
	 * Should an archive validation warning report fail the deployment
	 */
	@SuppressWarnings("unchecked")
	public ArchiveValidation failOnWarn(Boolean value) {
		this.failOnWarn = value;
		return (ArchiveValidation) this;
	}
}

==> config-api-0.3.10-sources.jar: org/wildfly/swarm/config/jca/ArchiveValidation.java <==
package org.wildfly.swarm.config.jca;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
/**
 * Archive validation for resource adapters
 */
@ResourceType("archive-validation")
@Implicit
public class ArchiveValidation<T extends ArchiveValidation> {

	private String key;
	private Boolean enabled;
	private Boolean failOnError;
	private Boolean failOnWarn;

	public ArchiveValidation() {
		this.key = "archive-validation";
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Specify whether archive validation is enabled
	 */
	@ModelNodeBinding(detypedName = "enabled")
	public Boolean enabled() {
		return this.enabled;
	}

	/**
	 * Specify whether archive validation is enabled
	 */
	@SuppressWarnings("unchecked")
	public ArchiveValidation enabled(Boolean value) {
		this.enabled = value;
		return (ArchiveValidation) this;
	}

	/**
	 * Should an archive validation error report fail the deployment
	 */
	@ModelNodeBinding(detypedName = "fail-on-error")
	public Boolean failOnError() {
		return this.failOnError;
	}

	/**
	 * Should an archive validation error report fail the deployment
	 */
	@SuppressWarnings("unchecked")
	public ArchiveValidation failOnError(Boolean value) {
		this.failOnError = value;
		return (ArchiveValidation) this;
	}

	/**
	 * Should an archive validation warning report fail the deployment
	 */
	@ModelNodeBinding(detypedName = "fail-on-warn")
	public Boolean failOnWarn() {
		return this.failOnWarn;
	}

	/**
	 * Should an archive validation warning report fail the deployment
	 */
	@SuppressWarnings("unchecked")
	public ArchiveValidation failOnWarn(Boolean value) {
		this.failOnWarn = value;
		return (ArchiveValidation) this;
	}
}
